Crate hivetuilib_board

Crate hivetuilib_board 

Modules

hypothetical
index_map
matrix_board
open_board
prelude
search
structures
vec_board

Structs

Bidirectional
Field

Traits

Board
BoardIdxType
BoardIndexable
BoardIntoFieldIter
BoardIntoIter
BoardMut
BoardToMap
ContiguousBoard
Emptyable
This trait is not intended to be used directly. It is used to provide generic access functionality on a higher level (e.g. for Fields).
IndexMap
Note that the iteration order should always be deterministic!